# TaskFingerprinting Package For Cognitive Personalization of Task Design

Source code for the  framework built for our study on assessing crowd workers behaviors for task design personalization in crowdsourcing. Beside crowdsourcing, this package can be used to perform cognitive personalization seamlessly in web tasks.
If you use our work in your research, please cite the following paper published at Sensors 2023.

> Dennis Paulino, Diogo Guimarães, António Correia, José Ribeiro, João Barroso and Hugo Paredes. A Model for Cognitive Personalization of Microtask Design. Sensors 2023, 23, 3571. https://doi.org/10.3390/s23073571 



The current implementation includes a module for performing task fingerprinting based on web interactions log and another module to develop a deep learning model based on the task fingerprinting data. Please refer to the paper for more details including deployment conditions.

### Contact

Please feel free to contact Dennis Paulino (dpaulino@utad.pt) for further questions.
